@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2003 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -23,7 +23,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "config.h"
-#include "libcharset.h"
+#include "localcharset.h"
 
 #if ENABLE_EXTRA
 /*
@@ -42,7 +42,7 @@
 #ifdef _AIX
 #define USE_AIX
 #endif
-#ifdef __osf__
+#if defined(__osf__) || defined(VMS)
 #define USE_OSF1
 #endif
 #if defined(__DJGPP__) || (defined(_WIN32) && (defined(_MSC_VER) || defined(__MINGW32__)))
@@ -544,4 +544,18 @@ void iconvlist (int (*do_one) (unsigned int namescount,
 
 int _libiconv_version = _LIBICONV_VERSION;
 
+#if defined __FreeBSD__ && !defined __gnu_freebsd__
+/* GNU libiconv is the native FreeBSD iconv implementation since 2002.
+   It wants to define the symbols 'iconv_open', 'iconv', 'iconv_close'.  */
+#define strong_alias(name, aliasname) _strong_alias(name, aliasname)
+#define _strong_alias(name, aliasname) \
+  extern __typeof (name) aliasname __attribute__ ((alias (#name)));
+#undef iconv_open
+#undef iconv
+#undef iconv_close
+strong_alias (libiconv_open, iconv_open)
+strong_alias (libiconv, iconv)
+strong_alias (libiconv_close, iconv_close)
+#endif
+
 #endif
